summaryrefslogtreecommitdiffstats
path: root/knode/kncomposer.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /knode/kncomposer.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'knode/kncomposer.h')
-rw-r--r--knode/kncomposer.h24
1 files changed, 15 insertions, 9 deletions
diff --git a/knode/kncomposer.h b/knode/kncomposer.h
index 05d6de0a..83b406be 100644
--- a/knode/kncomposer.h
+++ b/knode/kncomposer.h
@@ -44,6 +44,7 @@ class SpellingFilter;
class KNComposer : public KMainWindow , virtual public KNodeComposerIface {
Q_OBJECT
+ TQ_OBJECT
public:
enum composerResult { CRsendNow, CRsendLater, CRdelAsk,
@@ -52,7 +53,7 @@ class KNComposer : public KMainWindow , virtual public KNodeComposerIface {
// unwraped == original, not rewraped text
// firstEdit==true: place the cursor at the end of the article
- KNComposer(KNLocalArticle *a, const TQString &text=TQString::null, const TQString &sig=TQString::null, const TQString &unwraped=TQString::null, bool firstEdit=false, bool dislikesCopies=false, bool createCopy=false);
+ KNComposer(KNLocalArticle *a, const TQString &text=TQString(), const TQString &sig=TQString(), const TQString &unwraped=TQString(), bool firstEdit=false, bool dislikesCopies=false, bool createCopy=false);
~KNComposer();
void setConfig(bool onlyFonts);
void setMessageMode(MessageMode mode);
@@ -68,10 +69,10 @@ class KNComposer : public KMainWindow , virtual public KNodeComposerIface {
//set data from the given article
void initData(const TQString &text);
- // inserts at cursor position if clear is false, tqreplaces content otherwise
+ // inserts at cursor position if clear is false, replaces content otherwise
// puts the file content into a box if box==true
// "file" is already open for reading
- void insertFile(TQFile *file, bool clear=false, bool box=false, TQString boxTitle=TQString::null);
+ void insertFile(TQFile *file, bool clear=false, bool box=false, TQString boxTitle=TQString());
// ask for a filename, handle network urls
void insertFile(bool clear=false, bool box=false);
@@ -251,9 +252,10 @@ class KNComposer::ComposerView : public TQSplitter {
class KNComposer::Editor : public KEdit {
Q_OBJECT
+ TQ_OBJECT
public:
- Editor(KNComposer::ComposerView *_composerView, KNComposer *_composer, TQWidget *parent=0, char *name=0);
+ Editor(KNComposer::ComposerView *_composerView, KNComposer *_composer, TQWidget *tqparent=0, char *name=0);
~Editor();
TQStringList processedText();
@@ -295,7 +297,7 @@ private:
KNComposer *m_composer;
KNComposer::ComposerView *m_composerView;
KSpell *spell;
- TQMap<TQString,TQStringList> m_tqreplacements;
+ TQMap<TQString,TQStringList> m_replacements;
TQRegExp m_bound;
};
@@ -303,9 +305,10 @@ private:
class KNComposer::AttachmentView : public KListView {
Q_OBJECT
+ TQ_OBJECT
public:
- AttachmentView(TQWidget *parent, char *name=0);
+ AttachmentView(TQWidget *tqparent, char *name=0);
~AttachmentView();
protected:
@@ -330,6 +333,7 @@ class KNComposer::AttachmentViewItem : public KListViewItem {
class KNComposer::AttachmentPropertiesDlg : public KDialogBase {
Q_OBJECT
+ TQ_OBJECT
public:
AttachmentPropertiesDlg( KNAttachment *a, TQWidget *p=0, const char *n=0);
@@ -354,13 +358,14 @@ class KNComposer::AttachmentPropertiesDlg : public KDialogBase {
class KNLineEdit : public KABC::AddressLineEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef KABC::AddressLineEdit KNLineEditInherited;
public:
- KNLineEdit(KNComposer::ComposerView *_composerView, bool useCompletion, TQWidget *parent = 0,
+ KNLineEdit(KNComposer::ComposerView *_composerView, bool useCompletion, TQWidget *tqparent = 0,
const char *name = 0);
protected:
// Inherited. Always called by the parent when this widget is created.
virtual void loadAddresses();
void keyPressEvent(TQKeyEvent *e);
virtual TQPopupMenu *createPopupMenu();
@@ -373,8 +378,9 @@ private:
class KNLineEditSpell : public KNLineEdit
{
Q_OBJECT
+ TQ_OBJECT
public:
- KNLineEditSpell(KNComposer::ComposerView *_composerView, bool useCompletion,TQWidget * parent, const char * name = 0);
+ KNLineEditSpell(KNComposer::ComposerView *_composerView, bool useCompletion,TQWidget * tqparent, const char * name = 0);
void highLightWord( unsigned int length, unsigned int pos );
void spellCheckDone( const TQString &s );
void spellCheckerMisspelling( const TQString &text, const TQStringList &, unsigned int pos);
@@ -354,13 +358,14 @@ class KNComposer::AttachmentPropertiesDlg : public KDialogBase {
const char *name = 0);
protected:
- // Inherited. Always called by the parent when this widget is created.
+ // Inherited. Always called by the tqparent when this widget is created.
virtual void loadAddresses();
void keyPressEvent(TQKeyEvent *e);